Class: Lowkey::Proxy
- Inherits:
-
Object
- Object
- Lowkey::Proxy
- Extended by:
- Forwardable
- Defined in:
- lib/interfaces/proxy.rb
Overview
Proxy and Source abstract away nodes and avoid referencing the node on the proxy itself. Will this change? The goal is to make an API that's indiependent of the AST, that can manipulate source code line by line.
Direct Known Subclasses
BodyProxy, FileProxy, MethodProxy, ModuleProxy, ParamProxy, ReturnProxy
Instance Attribute Summary collapse
-
#name ⇒ Object
readonly
Returns the value of attribute name.
Instance Method Summary collapse
-
#initialize(name:, source:) ⇒ Proxy
constructor
A new instance of Proxy.
Constructor Details
#initialize(name:, source:) ⇒ Proxy
Returns a new instance of Proxy.
16 17 18 19 |
# File 'lib/interfaces/proxy.rb', line 16 def initialize(name:, source:) @name = name @source = source end |
Instance Attribute Details
#name ⇒ Object (readonly)
Returns the value of attribute name.
11 12 13 |
# File 'lib/interfaces/proxy.rb', line 11 def name @name end |